#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#------------------------------------------------------------------------------------------------
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
# IT WAS CREATED AND TESTED IN A WINDOWS ENVIRONMENT ONLY AND MAY NOT FUNCTION ON A MAC.
#------------------------------------------------------------------------------------------------
#    Name:	Export/Import Component Color
#      By:	sdmitch
#   Usage:	Sets an attribute to identify the component then outputs the RGB values of its color
#		 Note:	Color must be applied to the Component Instance as a whole not just to the entities
#						that make up the Component.  Components without material applied are ignored
#			
#    Date:	Dec 2011
#------------------------------------------------------------------------------------------------
#
	require 'sketchup'
#
if not file_loaded?(File.basename(__FILE__))
    sub = UI.menu('Plugins').add_submenu("Component Color")
	sub.add_item('Export Colors') { SDM_CLR.export_clr }
	sub.add_item('Import Colors') { SDM_CLR.import_clr }
	file_loaded(File.basename(__FILE__))
end
#
module SDM_CLR
#
	def self.export_clr
		mod=Sketchup.active_model
		ent=mod.entities
		sel=mod.selection
		if sel.empty?
			UI.messagebox "Select the Components to be exported to the .CSV file"
			return nil
		else
			@csv_dir = "c:/users/public/temp/" if !@csv_dir
			@csv_file = "comp_colors.csv" if !@csv_file
			export_file=UI.savepanel("File to export to:",@csv_dir,@csv_file)
			if !export_file then return end
			mod.start_operation "Export Component Colors"
			fo = File.open(export_file,"w")
			comps = sel.find_all{|c| c.class==Sketchup::ComponentInstance && c.material}
			comps.each{|c|
				cid = c.get_attribute("color","cid",nil)
				unless cid
					cid = Time.now.to_i + rand
					c.set_attribute("color","cid",cid.to_s)
				end
				fo.printf("%s,%d,%d,%d\n",cid,c.material.color.red,c.material.color.green,c.material.color.blue)
			}
			fo.close;sel.clear
			mod.commit_operation
		end
	end
#
	def self.import_clr
		mod=Sketchup.active_model
		ent=mod.entities
		sel=mod.selection
		@csv_dir = "c:/users/public/temp/" if !@csv_dir
		@csv_file = "comp_colors.csv" if !@csv_file
		import_file=UI.openpanel("File to import from:",@csv_dir,@csv_file)
		if !import_file then return end
		mod.start_operation "Import Component Colors"
		fi = File.open(import_file,"r")
		comps=ent.find_all{|c| c.class==Sketchup::ComponentInstance && c.material}
		while !fi.eof?
			dat = fi.readline;
			cid,red,grn,blu = dat.split(",")
			comps.each{|c|
				if c.get_attribute("color","cid",nil) == cid
					c.material=[red.to_i,grn.to_i,blu.to_i]
					break
				end
			}
		end
		fi.close
		mod.commit_operation
	end
#
end
